@@ -1,28 +1,14 @@
 /*
- * Copyright (C) 2014-2015 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "objectmanager.h"
 #include "object.h"
 
-#include <QDBusMetaType>
 #include <QDBusConnection>
+#include <QDBusMetaType>
 
 ObjectManager *s_instance = nullptr;
 
@@ -81,7 +67,7 @@ DBusManagerStruct ObjectManager::GetManagedObjects()
 {
     DBusManagerStruct objects;
 
-    Q_FOREACH (Object *object, m_objects.values()) {
+    for (Object *object : m_objects.values()) {
         if (objects.value(object->path()).isEmpty()) {
             objects[object->path()].insert(QStringLiteral("org.freedesktop.DBus.Introspectable"), QVariantMap());
             if (object->haveProperties()) {
@@ -93,3 +79,5 @@ DBusManagerStruct ObjectManager::GetManagedObjects()
 
     return objects;
 }
+
+#include "moc_objectmanager.cpp"
