@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
+
 #ifndef MANAGERTEST_H
 #define MANAGERTEST_H
 
@@ -9,7 +15,7 @@ class ManagerTest : public QObject
 
 private Q_SLOTS:
     void initTestCase();
-    void cleanupTestCase();
+    void cleanup();
 
     void bluezNotRunningTest();
     void bluezNotExportingInterfacesTest();
@@ -19,7 +25,9 @@ private Q_SLOTS:
 
     void usableAdapterTest();
     void deviceForAddressTest();
-
+    void adapterWithDevicesRemovedTest();
+    void bug364416();
+    void bug377405();
 };
 
 #endif // MANAGERTEST_H
