@@ -8,7 +8,6 @@
 
 #include "adapter.h"
 #include "adapter_p.h"
-#include "device.h"
 #include "device_p.h"
 #include "pendingcall.h"
 
@@ -147,7 +146,7 @@ QList<DevicePtr> Adapter::devices() const
 
 DevicePtr Adapter::deviceForAddress(const QString &address) const
 {
-    for (DevicePtr device : qAsConst(d->m_devices)) {
+    for (DevicePtr device : std::as_const(d->m_devices)) {
         if (device->address() == address) {
             return device;
         }
@@ -170,4 +169,16 @@ PendingCall *Adapter::removeDevice(DevicePtr device)
     return new PendingCall(d->m_bluezAdapter->RemoveDevice(QDBusObjectPath(device->ubi())), PendingCall::ReturnVoid, this);
 }
 
+PendingCall* Adapter::setDiscoveryFilter(const QVariantMap& filter)
+{
+    return new PendingCall(d->m_bluezAdapter->SetDiscoveryFilter(filter), PendingCall::ReturnVoid, this);
+}
+
+PendingCall* Adapter::getDiscoveryFilters()
+{
+    return new PendingCall(d->m_bluezAdapter->GetDiscoveryFilters(), PendingCall::ReturnStringList, this);
+}
+
 } // namespace BluezQt
+
+#include "moc_adapter.cpp"
