@@ -6,21 +6,24 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#pragma once
+#ifndef BLUEZQT_GATTMANAGER_P_H
+#define BLUEZQT_GATTMANAGER_P_H
+
+#include "bluezgattmanager1.h"
 
-class QDBusInterface;
 class QString;
 
 namespace BluezQt
 {
-
 class GattManagerPrivate
 {
 public:
     GattManagerPrivate(const QString &path);
     ~GattManagerPrivate();
 
-    QDBusInterface *m_dbusInterface = nullptr;
+    OrgBluezGattManager1Interface m_dbusInterface;
 };
 
 } // namespace BluezQt
+
+#endif
