@@ -11,9 +11,9 @@
 
 #include <QObject>
 
+#include "bluezqt_export.h"
 #include "request.h"
 #include "types.h"
-#include "bluezqt_export.h"
 
 class QLocalSocket;
 class QDBusObjectPath;
@@ -21,7 +21,6 @@ class QDBusUnixFileDescriptor;
 
 namespace BluezQt
 {
-
 class Device;
 
 /**
@@ -56,7 +55,7 @@ public:
         /** Indicates that this is a client. */
         ClientRole,
         /** Indicates that this is a server. */
-        ServerRole
+        ServerRole,
     };
 
     /**
@@ -69,7 +68,7 @@ public:
     /**
      * Destroys a Profile object.
      */
-    ~Profile();
+    ~Profile() override;
 
     /**
      * D-Bus object path of the profile.
